% nexus_fem.m
% MATLAB Script, which assembles the Nexus FEM
% Note some modifications have been made from the
% original NASTRAN model.
% Version 2.0
% Monday, 4 June 2001, dWo

% NEXUS FEM design parameters
% m_SM=2.49; %SM mass
m_SMhub=4.4;  %SM hub mass
I_SMhubt=0.25200E+00; %SM hub inertia transverse
I_SMhuba=0.45900E+00; %SM hub inertia axial
m_RW=0.10600E+02; % RW mass (ITHACO E-wheel)
% K_yPM=0.77400E+06; %PM outer bipod actuator transverse stiffness
I_xRWA=0.40187E+00;  % Ix moment of inertia of RWA chassis
I_yRWA=0.22445E+00;  % Iy moment of inertia of RWA chassis
I_zRWA=I_yRWA; % Iz moment of inertia of RWA chassis
I_RWt=0.83595E-01; % Transverse Inertia of ITHACO E reaction wheel
I_RWa=0.14339E+00; % Axial Inertia of ITHACO E reaction wheel
m_ISO=0.15E+01;  % mass of RWA isolator strut actuator
I_ISOa=0.11720E-03;  % RWA isolator strut axial inertia
I_ISOt=0.39300E-01;  % RWA isolator strut transverse inertia
K_yISO=0.14600E+04;  % Hexapod isolator strut axial stiffness
K_xISO=0.14000E+12;  % Hexapod isolator strut transverse stiffness
m_RWAchx=0.25000E+01; % mass RWA pyramid chassis
I_bus=0.85080E+02;    % NEXUS spacecraft bus principal inertia
% m_bus=0.33200E+03;    % NEXUS spacecraft bus mass
m_prop=0.37000E+02;   % propulsion system mass (incl. propellant)
% I_propt=0.51100E+01;  % propulsion system transverse inertia 
I_propa=0.74000E+00;  % propulsion system axial inertia
m_instr=0.50000E+02;  % instrument mass (incl. CCD detector)
I_i1=0.49200E+01;  % Instrument moment of inertia 1-axis
I_i2=0.75420E+01;  % Instrument moment of inertia 2-axis
I_i3=0.41280E+01;  % Instrument moment of inertia 3-axis
% SM supporting structure (spider): Tangential Bipod design
A_sptop=0.14040E-02;  % Cross sectional area of SM spider (top)
%t_sp=0.003;           % SM spider (bottom) wall thickness
D_sp=0.060;           % SM spider (bottom) diameter
A_spbot=(pi/4)*(D_sp^2-(D_sp-2*t_sp)^2); % Cross sectional area of SM spider (bottom)
J_sp=(pi/32)*(D_sp^4-(D_sp-2*t_sp)^4);   % SM Spider torsional moment of inertia
I_sp=(pi/64)*(D_sp^4-(D_sp-2*t_sp)^4);   % SM Spider bending moment of inertia
% I_ss=0.78350E-08;                        % Sunshield out-of-plane bending moment of inertia,
K_rad1=0.50000E+6;   % rotational stiffness of SM and PM actuators in 1 direction
K_rad2=0.30000E+6;   % rotational stiffness of SM and PM actuators in 2 direction 
%K_rISO=0.30000E+2;   % rot stiff RWA iso struts 
K_aISO=(5/3)*K_rISO; % axial rot RWA iso struts 
K_act1=0.20000E+11;  % actuator axial stiffness 
K_act2=0.14000E+12;  % actuator radial stiffness +12
I_iso=1.00000E-5;    % RW wheel isolator bending m.o.I. [m^4]
%K_zpet=0.9000E+08;  % Deployable petal hinge stiffness [N/m] (nom:0.90000E+08)
%Note: Inertias in units of kgm^2
%Note: Stiffnesses in units of N/m  or Nm/rad
%Note: Masses in units of kg

% important grids for dynamics analysis


% ======================================
% 1. Create grid location matrix
% ======================================
       xyz=[ ...
       1  0.00000E+00  3.41300E+00  2.72000E-01
       2  0.00000E+00  2.87800E+00  7.20000E-01
       3 -2.35560E-01  3.41300E+00 -1.36000E-01
       4 -6.23540E-01  2.87800E+00 -3.60000E-01
       5  2.35560E-01  3.41300E+00 -1.36000E-01
       6  6.23540E-01  2.87800E+00 -3.60000E-01
       7 -6.50000E-01  0.00000E+00  1.10000E+00
       8  6.50000E-01  0.00000E+00  1.10000E+00
       9 -1.13800E+00  0.00000E+00 -6.30000E-02
      10 -6.50000E-01  0.00000E+00 -9.07000E-01
      11  6.50000E-01  0.00000E+00 -9.07000E-01
      12  1.13800E+00  0.00000E+00 -6.30000E-02
      13  0.00000E+00  3.41300E+00  0.00000E+00
      14 -1.89470E-01  3.45930E+00 -1.23830E-01
      15 -2.01970E-01  3.45930E+00 -1.02170E-01
      16  1.89470E-01  3.45930E+00 -1.23830E-01
      17  2.01970E-01  3.45930E+00 -1.02170E-01
      18 -1.25000E-02  3.45930E+00  2.26000E-01
      19  1.25000E-02  3.45930E+00  2.26000E-01
      20 -9.88200E-02  3.32485E+00  4.23890E-02
      21 -8.61200E-02  3.32485E+00  6.43860E-02
      22  0.00000E+00  3.29369E+00  0.00000E+00
      23 -1.27000E-02  3.32485E+00 -1.06780E-01
      24  1.27000E-02  3.32485E+00 -1.06780E-01
      25  8.61200E-02  3.32485E+00  6.43860E-02
      26  9.88200E-02  3.32485E+00  4.23890E-02
      27  6.15960E-01 -3.08310E-01  1.72528E+00
      28 -6.15960E-01 -3.08310E-01  1.72528E+00
      29  0.00000E+00  1.24610E-01 -2.37940E-01
      30 -6.15960E-01 -1.46593E+00  1.30394E+00
      31 -9.88200E-02  3.32485E+00  4.23890E-02
      32 -8.61200E-02  3.32485E+00  6.43860E-02
      33  8.61200E-02  3.32485E+00  6.43860E-02
      34  9.88200E-02  3.32485E+00  4.23890E-02
      35  1.27000E-02  3.32485E+00 -1.06780E-01
      36 -1.27000E-02  3.32485E+00 -1.06780E-01
      37 -1.89470E-01  3.45930E+00 -1.23830E-01
      38 -2.01970E-01  3.45930E+00 -1.02170E-01
      39 -1.25000E-02  3.45930E+00  2.26000E-01
      40  1.25000E-02  3.45930E+00  2.26000E-01
      41  2.01970E-01  3.45930E+00 -1.02170E-01
      42  1.89470E-01  3.45930E+00 -1.23830E-01
      43  6.15960E-01 -8.87120E-01  1.51461E+00
      44  0.00000E+00 -3.08310E-01  1.72528E+00
      45 -6.15960E-01 -8.87120E-01  1.51461E+00
      46  0.00000E+00 -1.46593E+00  1.30394E+00
      47  0.00000E+00 -1.79290E+00  2.20228E+00
      48  6.15960E-01 -1.21409E+00  2.41295E+00
      49  0.00000E+00 -6.35280E-01  2.62362E+00
      50 -6.15960E-01 -1.21409E+00  2.41295E+00
      51  3.61596E+00  9.56000E-01  0.00000E+00
      52  0.00000E+00  9.56000E-01 -3.61596E+00
      53 -3.61596E+00  9.56000E-01  0.00000E+00
      55  0.00000E+00  9.56000E-01  6.21596E+00
      56 -3.81596E+00  0.00000E+00  0.00000E+00
      57  3.81596E+00  0.00000E+00  0.00000E+00
      58  0.00000E+00  0.00000E+00  0.00000E+00
      59  0.00000E+00 -2.17070E+00  1.04742E+00
      60  0.00000E+00 -2.87547E+00  7.90910E-01
      61  0.00000E+00 -3.58024E+00  5.34390E-01
      62  1.36596E+00 -8.87120E-01  1.51461E+00
      63  2.11596E+00 -8.87120E-01  1.51461E+00
      64  6.15960E-01 -1.46593E+00  1.30394E+00
      65  2.86596E+00 -8.87120E-01  1.51461E+00
      66 -1.36596E+00 -8.87120E-01  1.51461E+00
      67 -6.90000E-01  0.00000E+00 -1.50000E-01
      68  6.90000E-01  0.00000E+00 -1.50000E-01
      69  6.15960E-01 -6.35280E-01  2.62362E+00
      70 -6.15960E-01 -6.35280E-01  2.62362E+00
      71 -6.15960E-01 -1.79290E+00  2.20228E+00
      72  6.15960E-01 -1.79290E+00  2.20228E+00
      73 -6.54380E-01 -6.65870E-01  1.63769E+00
      74 -4.04380E-01 -5.79050E-01  2.13009E+00
      75 -6.54380E-01 -9.62070E-01  2.45148E+00
      76 -4.04380E-01 -1.43192E+00  2.28047E+00
      77 -6.54380E-01 -1.51874E+00  1.78807E+00
      78 -4.04380E-01 -1.13572E+00  1.46668E+00
      79 -4.74130E-01 -8.13750E-01  2.04467E+00
      80 -4.74130E-01 -9.63310E-01  1.72393E+00
      81 -4.74130E-01 -1.28405E+00  1.87349E+00
      82 -4.74130E-01 -1.13448E+00  2.19423E+00
      83 -5.67280E-01 -1.04890E+00  1.95908E+00
      84  0.00000E+00 -1.05061E+00  1.96378E+00
      85 -6.54380E-01 -6.65870E-01  1.63769E+00
      86 -4.04380E-01 -5.79050E-01  2.13009E+00
      87 -6.54380E-01 -9.62070E-01  2.45148E+00
      88 -4.04380E-01 -1.43192E+00  2.28047E+00
      89 -6.54380E-01 -1.51874E+00  1.78807E+00
      90 -4.04380E-01 -1.13572E+00  1.46668E+00
      91  0.00000E+00  0.00000E+00  0.00000E+00
      92 -2.11596E+00 -8.87120E-01  1.51461E+00
      93 -2.86596E+00 -8.87120E-01  1.51461E+00
      94  0.00000E+00  1.00726E+00  2.20410E+00
      95  0.00000E+00  2.32283E+00  2.68293E+00
      96  0.00000E+00  3.63840E+00  3.16176E+00
      97 -5.29380E-01 -9.00800E-01  1.55218E+00
      98 -5.29380E-01 -6.22460E-01  1.88389E+00
      99 -5.29380E-01 -1.32723E+00  1.62737E+00
     100 -5.29380E-01 -1.47533E+00  2.03427E+00
     101 -5.29380E-01 -7.70560E-01  2.29079E+00
     102 -5.29380E-01 -1.19700E+00  2.36598E+00
     103 -6.54380E-01 -6.65870E-01  1.63769E+00
     104 -6.54380E-01 -6.65870E-01  1.63769E+00
     105 -6.54380E-01 -9.62070E-01  2.45148E+00
     106 -6.54380E-01 -9.62070E-01  2.45148E+00
     107 -6.54380E-01 -1.51874E+00  1.78807E+00
     108 -6.54380E-01 -1.51874E+00  1.78807E+00
     109 -4.04380E-01 -5.79050E-01  2.13009E+00
     110 -4.04380E-01 -1.43192E+00  2.28047E+00
     111 -4.04380E-01 -1.13572E+00  1.46668E+00
     112 -4.04380E-01 -5.79050E-01  2.13009E+00
     113 -4.04380E-01 -1.43192E+00  2.28047E+00
     114 -4.04380E-01 -1.13572E+00  1.46668E+00
     115  4.34740E-01  1.54070E-01 -4.87220E-01
     116  1.01090E-01  3.39207E+00 -1.15300E-01
     117 -1.01090E-01  3.39207E+00 -1.15300E-01
     118 -1.50400E-01  3.39207E+00 -2.99000E-02
     119 -4.93100E-02  3.39208E+00  1.45190E-01
     120  4.93100E-02  3.39207E+00  1.45190E-01
     121  1.50400E-01  3.39207E+00 -2.99000E-02
     122  4.34740E-01  2.07420E-01 -9.86380E-01
     123  0.00000E+00  2.32800E-01 -1.23610E+00
     124 -4.34740E-01  2.07420E-01 -9.86380E-01
     125 -4.34740E-01  1.54070E-01 -4.87220E-01
     126  0.00000E+00  1.51070E-01 -6.23780E-01
     127  1.00030E-01  1.70140E-01 -7.95980E-01
     128 -1.00030E-01  1.70140E-01 -7.95980E-01
     129  0.00000E+00  2.24540E-01 -7.32210E-01
     130  0.00000E+00  2.06200E-01 -7.28870E-01
     131 -4.34740E-01  2.07420E-01 -9.86380E-01
     132  0.00000E+00  2.32800E-01 -1.23610E+00
     133  4.34740E-01  2.07420E-01 -9.86380E-01
     134  4.34740E-01  1.54070E-01 -4.87220E-01
     135  0.00000E+00  1.24610E-01 -2.37940E-01
     136 -4.34740E-01  1.54070E-01 -4.87220E-01
     137  0.00000E+00  1.51070E-01 -6.23780E-01
     138 -1.00030E-01  1.70140E-01 -7.95980E-01
     139  1.00030E-01  1.70140E-01 -7.95980E-01
     140  2.06060E-01  1.24610E-01  1.18970E-01
     141  2.04570E-01  1.54070E-01  6.20110E-01
     142  6.36860E-01  2.07420E-01  8.69690E-01
     143  1.07049E+00  2.32800E-01  6.18050E-01
     144  1.07160E+00  2.07420E-01  1.16690E-01
     145  6.39320E-01  1.54070E-01 -1.32890E-01
     146  5.40210E-01  1.51070E-01  3.11890E-01
     147  6.39330E-01  1.70140E-01  4.84610E-01
     148  7.39350E-01  1.70140E-01  3.11360E-01
     149  6.34110E-01  2.24540E-01  3.66100E-01
     150  6.31220E-01  2.06200E-01  3.64430E-01
     151  1.07160E+00  2.07420E-01  1.16690E-01
     152  1.07049E+00  2.32800E-01  6.18050E-01
     153  6.36860E-01  2.07420E-01  8.69690E-01
     154  2.04570E-01  1.54070E-01  6.20110E-01
     155  2.06060E-01  1.24610E-01  1.18970E-01
     156  6.39320E-01  1.54070E-01 -1.32890E-01
     157  5.40210E-01  1.51070E-01  3.11890E-01
     158  7.39350E-01  1.70140E-01  3.11360E-01
     159  6.39330E-01  1.70140E-01  4.84610E-01
     160 -2.06060E-01  1.24610E-01  1.18970E-01
     161 -6.39320E-01  1.54070E-01 -1.32890E-01
     162 -1.07160E+00  2.07420E-01  1.16690E-01
     163 -1.07049E+00  2.32800E-01  6.18050E-01
     164 -6.36860E-01  2.07420E-01  8.69690E-01
     165 -2.04570E-01  1.54070E-01  6.20110E-01
     166 -5.40210E-01  1.51070E-01  3.11890E-01
     167 -7.39350E-01  1.70140E-01  3.11360E-01
     168 -6.39330E-01  1.70140E-01  4.84610E-01
     169 -6.34110E-01  2.24540E-01  3.66110E-01
     170 -6.31220E-01  2.06200E-01  3.64440E-01
     171 -6.36860E-01  2.07420E-01  8.69690E-01
     172 -1.07049E+00  2.32800E-01  6.18050E-01
     173 -1.07160E+00  2.07420E-01  1.16690E-01
     174 -6.39320E-01  1.54070E-01 -1.32890E-01
     175 -2.06060E-01  1.24610E-01  1.18970E-01
     176 -2.04570E-01  1.54070E-01  6.20110E-01
     177 -5.40210E-01  1.51070E-01  3.11890E-01
     178 -6.39330E-01  1.70140E-01  4.84610E-01
     179 -7.39350E-01  1.70140E-01  3.11360E-01
     180 -2.17370E-01  2.20110E-01 -1.11124E+00
     181  4.34740E-01  1.80750E-01 -7.36800E-01
     182 -2.17370E-01  1.39340E-01 -3.62580E-01
     183 -8.55460E-01  1.80750E-01 -8.10000E-03
     184 -2.05320E-01  1.39340E-01  3.69540E-01
     185 -8.53670E-01  2.20110E-01  7.43870E-01
     190 -4.34740E-01  5.10000E-02 -1.62940E-01
     191 -4.34740E-01 -5.10000E-02 -1.62940E-01
     192  4.34740E-01  5.10000E-02 -1.62940E-01
     193  4.34740E-01 -5.10000E-02 -1.62940E-01
     194 -1.31000E-02  3.24000E-02 -6.41000E-01
     195 -4.34740E-01 -5.10000E-02 -1.62940E-01
     196 -4.34740E-01  5.10000E-02 -1.62940E-01
     197  4.34740E-01  5.10000E-02 -1.62940E-01
     198  4.34740E-01 -5.10000E-02 -1.62940E-01
     199  8.53670E-01  2.20110E-01  7.43870E-01
     200  8.55460E-01  1.80750E-01 -8.10000E-03
     201  2.05320E-01  1.39340E-01  3.69540E-01
     202  0.00000E+00  3.25485E+00  0.00000E+00
     203  3.81596E+00  0.00000E+00 -6.25000E-01
     204  3.81596E+00  0.00000E+00  6.25000E-01
     205 -3.81596E+00  0.00000E+00  6.25000E-01
     206 -3.81596E+00  0.00000E+00 -6.25000E-01
     207  0.00000E+00 -5.25000E-01 -3.50000E-01
     208  1.14929E+00 -1.21409E+00  2.41295E+00
     209  1.68262E+00 -1.21409E+00  2.41295E+00
     210  2.21596E+00 -1.21409E+00  2.41295E+00
     211  2.74929E+00 -1.21409E+00  2.41295E+00
     212  3.28262E+00 -1.21409E+00  2.41295E+00
     213 -1.14929E+00 -1.21409E+00  2.41295E+00
     214 -1.68262E+00 -1.21409E+00  2.41295E+00
     215 -2.21596E+00 -1.21409E+00  2.41295E+00
     216 -2.74929E+00 -1.21409E+00  2.41295E+00
     217 -3.28262E+00 -1.21409E+00  2.41295E+00
     218  0.00000E+00 -1.81832E+00  1.17568E+00
     219  9.90960E-01 -8.87120E-01  1.51461E+00
     220 -9.90960E-01 -8.87120E-01  1.51461E+00
     221 -4.29550E-01  3.14550E+00 -2.48000E-01
     222  0.00000E+00  3.14550E+00  4.96000E-01
     223  4.29550E-01  3.14550E+00 -2.48000E-01
     224  0.00000E+00  3.49470E-01  1.96469E+00
     225  0.00000E+00 -2.52309E+00  9.19160E-01
     226  0.00000E+00 -3.22785E+00  6.62650E-01
     227  0.00000E+00 -3.93262E+00  4.06130E-01
     228  1.74096E+00 -8.87120E-01  1.51461E+00
     229  2.49096E+00 -8.87120E-01  1.51461E+00
     230  3.24096E+00 -8.87120E-01  1.51461E+00
     231 -1.74096E+00 -8.87120E-01  1.51461E+00
     232 -2.49096E+00 -8.87120E-01  1.51461E+00
     233 -3.24096E+00 -8.87120E-01  1.51461E+00
     234  0.00000E+00  1.66504E+00  2.44352E+00
     235  0.00000E+00  2.98061E+00  2.92235E+00
     236  0.00000E+00  4.29618E+00  3.40117E+00
     237 -4.87500E-01  7.19500E-01  1.00500E+00
     238 -3.25000E-01  1.43900E+00  9.10000E-01
     239 -1.62500E-01  2.15850E+00  8.15000E-01
     240  4.87500E-01  7.19500E-01  1.00500E+00
     241  3.25000E-01  1.43900E+00  9.10000E-01
     242  1.62500E-01  2.15850E+00  8.15000E-01
     243  1.00938E+00  7.19500E-01 -1.37250E-01
     244  8.80770E-01  1.43900E+00 -2.11500E-01
     245  7.52150E-01  2.15850E+00 -2.85750E-01
     246  6.43380E-01  7.19500E-01 -7.70250E-01
     247  6.36770E-01  1.43900E+00 -6.33500E-01
     248  6.30150E-01  2.15850E+00 -4.96750E-01
     249 -1.00938E+00  7.19500E-01 -1.37250E-01
     250 -8.80770E-01  1.43900E+00 -2.11500E-01
     251 -7.52150E-01  2.15850E+00 -2.85750E-01
     252 -6.43380E-01  7.19500E-01 -7.70250E-01
     253 -6.36770E-01  1.43900E+00 -6.33500E-01
     254 -6.30150E-01  2.15850E+00 -4.96750E-01
     255  6.24470E-01 -2.31230E-01  1.56896E+00
     256  6.32980E-01 -1.54160E-01  1.41264E+00
     257  6.41490E-01 -7.71000E-02  1.25632E+00
     258 -6.24470E-01 -2.31230E-01  1.56896E+00
     259 -6.32980E-01 -1.54160E-01  1.41264E+00
     260 -6.41490E-01 -7.71000E-02  1.25632E+00
     261  2.99470E-01 -2.31230E-01  1.56896E+00
     262 -1.70000E-02 -1.54160E-01  1.41264E+00
     263 -3.33510E-01 -7.71000E-02  1.25632E+00
     264 -2.99470E-01 -2.31230E-01  1.56896E+00
     265  1.70210E-02 -1.54160E-01  1.41264E+00
     266  3.33510E-01 -7.71000E-02  1.25632E+00
     267 -6.34470E-01 -1.09945E+00  9.40450E-01
     268 -6.52980E-01 -7.32970E-01  5.76970E-01
     269 -6.71490E-01 -3.66480E-01  2.13480E-01
     270  6.34470E-01 -1.09945E+00  9.40450E-01
     271  6.52980E-01 -7.32970E-01  5.76970E-01
     272  6.71490E-01 -3.66480E-01  2.13480E-01
     273 -6.24470E-01 -1.09945E+00  1.25295E+00
     274 -6.32980E-01 -7.32970E-01  1.20197E+00
     275 -6.41490E-01 -3.66480E-01  1.15098E+00
     276  6.24470E-01 -1.09945E+00  1.25295E+00
     277  6.32980E-01 -7.32970E-01  1.20197E+00
     278  6.41490E-01 -3.66480E-01  1.15098E+00 ];
  
     [s,si]=sort(xyz(:,1));
     xyz=xyz(si,:);
     clear s si
  
  %====================================================
  % 2. Local to Basic coordinate system transformations
  %====================================================
  % Create coord system index matrix: grid id, input csid , output csid
  %  (0= basic)
      ci=[ ...
      14       0      79
      15       0      78
      16       0      80
      17       0      75
      18       0      77
      19       0      76
      20       0      78
      21       0      77
      23       0      79
      24       0      80
      25       0      76
      26       0      75
      29       0      16
      31       0      78
      32       0      77
      33       0      76
      34       0      75
      35       0      80
      36       0      79
      37       0      79
      38       0      78
      39       0      77
      40       0      76
      41       0      75
      42       0      80
      51       3       0
      52       3       0
      53       3       0
      55       3       0
      56       3       0
      57       3       0
      58       3       0
      73       0      10
      74       0      10
      75       0      12
      76       0      12
      77       0       8
      78       0       8
      85       0      10
      86       0      10
      87       0      12
      88       0      12
      89       0       8
      90       0       8
     103       0       9
     104       0       9
     105       0      11
     106       0      11
     107       0      13
     108       0      13
     109       0      11
     110       0      13
     111       0       9
     112       0      11
     113       0      13
     114       0       9
     115       0      15
     122       0      15
     123       0      14
     124       0      14
     125       0      16
     126       0      17
     127       0      18
     128       0      19
     131       0      14
     132       0      14
     133       0      15
     134       0      15
     135       0      16
     136       0      16
     137       0      17
     138       0      19
     139       0      18
     140       0      22
     141       0      22
     142       0      25
     143       0      25
     144       0      24
     145       0      24
     146       0      29
     147       0      31
     148       0      30
     151       0      24
     152       0      25
     153       0      25
     154       0      22
     155       0      22
     156       0      24
     157       0      29
     158       0      30
     159       0      31
     160       0      26
     161       0      28
     162       0      28
     163       0      27
     164       0      27
     165       0      26
     166       0      34
     167       0      33
     168       0      32
     171       0      27
     172       0      27
     173       0      28
     174       0      28
     175       0      26
     176       0      26
     177       0      34
     178       0      32
     179       0      33
     203       3       0
     204       3       0
     205       3       0
     206       3       0 ];
 
% Create coordinate system definition matrix
       cf=[ ...
       1       2       0  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.10000E+01  0.10000E+01  0.00000E+00  0.10000E+01
       2       3       0  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.10000E+01  0.10000E+01  0.00000E+00  0.10000E+01
       3       1       0  0.00000E+00 -0.12141E+01  0.24129E+01  0.00000E+00 -0.27440E+00  0.27550E+01  0.10000E+01 -0.12141E+01  0.24129E+01
       4       1       0 -0.47413E+00 -0.81375E+00  0.20447E+01 -0.14113E+01 -0.48596E+00  0.21640E+01 -0.47413E+00 -0.47173E+00  0.11050E+01
       5       1       0 -0.47413E+00 -0.96331E+00  0.17239E+01 -0.14113E+01 -0.84400E+00  0.13961E+01 -0.47413E+00 -0.19030E+01  0.13819E+01
       6       1       0 -0.47413E+00 -0.12840E+01  0.18735E+01 -0.14113E+01 -0.16118E+01  0.17542E+01 -0.47413E+00 -0.16261E+01  0.28132E+01
       7       1       0 -0.47413E+00 -0.11345E+01  0.21942E+01 -0.14113E+01 -0.12538E+01  0.25220E+01 -0.47413E+00 -0.19479E+00  0.25362E+01
       8       1       0 -0.40438E+00 -0.11357E+01  0.14667E+01 -0.95210E+00 -0.41776E+00  0.18962E+01 -0.11115E+01 -0.12585E+01  0.77031E+00
       9       1       0 -0.40438E+00 -0.11357E+01  0.14667E+01 -0.95210E+00 -0.16635E+01  0.21159E+01  0.30273E+00 -0.10129E+01  0.21630E+01
      10       1       0 -0.40438E+00 -0.57905E+00  0.21301E+01 -0.95210E+00 -0.13100E+01  0.25371E+01 -0.11115E+01  0.85413E-01  0.23719E+01
      11       1       0 -0.40438E+00 -0.57905E+00  0.21301E+01 -0.95210E+00 -0.87743E+00  0.13484E+01  0.30273E+00 -0.12435E+01  0.18882E+01
      12       1       0 -0.40438E+00 -0.14319E+01  0.22805E+01 -0.95210E+00 -0.14189E+01  0.14439E+01 -0.11115E+01 -0.19736E+01  0.27350E+01
      13       1       0 -0.40438E+00 -0.14319E+01  0.22805E+01 -0.95210E+00 -0.60580E+00  0.24129E+01  0.30273E+00 -0.89024E+00  0.18259E+01
      14       1       0 -0.43474E+00  0.20742E+00 -0.98638E+00  0.65255E-01  0.11713E+00 -0.12507E+00  0.43128E+00  0.25955E+00 -0.14837E+01
      15       1       0  0.43474E+00  0.20742E+00 -0.98638E+00 -0.56526E+00  0.20742E+00 -0.98638E+00  0.43474E+00  0.10316E+00  0.81700E-02
      16       1       0  0.00000E+00  0.12461E+00 -0.23794E+00  0.50000E+00  0.21491E+00 -0.10992E+01 -0.86603E+00  0.17674E+00 -0.73521E+00
      17       1       0  0.00000E+00  0.15107E+00 -0.62378E+00  0.00000E+00  0.46806E-01  0.37077E+00  0.10000E+01  0.15107E+00 -0.62378E+00
      18       1       0  0.10003E+00  0.17014E+00 -0.79598E+00  0.96605E+00  0.22227E+00 -0.12933E+01 -0.39997E+00  0.26043E+00 -0.16573E+01
      19       1       0 -0.10003E+00  0.17014E+00 -0.79598E+00 -0.96605E+00  0.22227E+00 -0.12933E+01 -0.60003E+00  0.79849E-01  0.65326E-01
      22       1       0  0.20606E+00  0.12461E+00  0.11897E+00  0.12020E+01  0.21490E+00  0.11661E+00  0.20842E+00  0.72476E-01 -0.87967E+00
      24       1       0  0.10716E+01  0.20742E+00  0.11669E+00  0.57160E+00  0.20742E+00  0.98272E+00  0.19329E+01  0.31168E+00  0.61397E+00
      25       1       0  0.63686E+00  0.20742E+00  0.86969E+00  0.14095E+00  0.11713E+00  0.60250E-02 -0.22681E+00  0.15529E+00  0.13711E+01
      26       1       0 -0.20606E+00  0.12461E+00  0.11897E+00 -0.12020E+01  0.21490E+00  0.11661E+00 -0.20370E+00  0.17674E+00  0.11176E+01
      27       1       0 -0.63686E+00  0.20742E+00  0.86969E+00 -0.14095E+00  0.11713E+00  0.60250E-02 -0.15005E+01  0.25955E+00  0.36833E+00
      28       1       0 -0.10716E+01  0.20742E+00  0.11669E+00 -0.57160E+00  0.20742E+00  0.98272E+00 -0.21030E+00  0.10316E+00 -0.38058E+00
      29       1       0  0.54021E+00  0.15107E+00  0.31189E+00 -0.32110E+00  0.46806E-01 -0.18539E+00  0.40209E-01  0.15107E+00  0.11779E+01
      30       1       0  0.73935E+00  0.17014E+00  0.31136E+00  0.16030E+01  0.22227E+00 -0.19000E+00  0.24344E+00  0.79849E-01 -0.55230E+00
      31       1       0  0.63933E+00  0.17014E+00  0.48461E+00  0.63697E+00  0.22227E+00  0.14832E+01  0.16352E+01  0.26043E+00  0.48225E+00
      32       1       0 -0.63933E+00  0.17014E+00  0.48461E+00 -0.63697E+00  0.22227E+00  0.14832E+01  0.35659E+00  0.79849E-01  0.48697E+00
      33       1       0 -0.73935E+00  0.17014E+00  0.31136E+00 -0.16030E+01  0.22227E+00 -0.19000E+00 -0.12353E+01  0.26043E+00  0.11750E+01
      34       1       0 -0.54021E+00  0.15107E+00  0.31189E+00  0.32110E+00  0.46806E-01 -0.18539E+00 -0.10402E+01  0.15107E+00 -0.55414E+00
      75       1       0  0.20197E+00  0.34593E+01 -0.10217E+00 -0.65717E+00  0.35851E+01 -0.59820E+00 -0.26112E+00  0.28557E+01  0.54683E+00
      76       1       0  0.12500E-01  0.34593E+01  0.22600E+00  0.87164E+00  0.33335E+01  0.72203E+00  0.34301E+00  0.28557E+01 -0.49955E+00
      77       1       0 -0.12500E-01  0.34593E+01  0.22600E+00  0.84664E+00  0.35851E+01 -0.27003E+00 -0.34301E+00  0.28557E+01 -0.49955E+00
      78       1       0 -0.20197E+00  0.34593E+01 -0.10217E+00 -0.10611E+01  0.33335E+01  0.39385E+00  0.26112E+00  0.28557E+01  0.54683E+00
      79       1       0 -0.18947E+00  0.34593E+01 -0.12383E+00 -0.18947E+00  0.35851E+01  0.86823E+00  0.60413E+00  0.28557E+01 -0.47300E-01
      80       1       0  0.18947E+00  0.34593E+01 -0.12383E+00  0.18947E+00  0.33335E+01 -0.11159E+01 -0.60413E+00  0.28557E+01 -0.47300E-01
  ];
  
%  compute cs tranformation matrices and xyz in basic
xyzi= xyz; % save xyz before coord_in processing as xyzi
[ti,tf,xyz]=coord_in(ci,cf,xyz);

%==============================================================
% 3. Create FEM Element connectivity (nodal incidence matrices)
%==============================================================
       % Create bar element connectivity matrix
       nibar=[ ...
       1      46     218       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
       2      43     219       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
       3      45     220       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
       4       7     237       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
       5       8     240       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
       6      12     243       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
       7      11     246       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
       8       9     249       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
       9      10     252       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
      14      27     255       0      11       0       0  0.00000E+00  1.00000E+00  0.00000E+00
      26      28     258       0      11       0       0  0.00000E+00  1.00000E+00  0.00000E+00
      94       3     221       0       1       0       0  0.00000E+00  1.00000E+00  0.00000E+00
      95       1     222       0       1       0       0  0.00000E+00  1.00000E+00  0.00000E+00
      96       5     223       0       1       0       0  0.00000E+00  1.00000E+00  0.00000E+00
      97      44     224       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
      98      48     208       0      22       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
      99      50     213       0      22       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     108      59     225       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     109      60     226       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     110      61     227       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     111      62     228       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     112      63     229       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     113      65     230       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     114      66     231       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     115      27     261       0      12       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     116      28     264       0      12       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     117      92     232       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     118      93     233       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     119      94     234       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     120      95     235       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     121      30     267       0      13       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     122      64     270       0      13       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     131      30     273       0      14       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     132      64     276       0      14       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     134      96     236       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     415     208     209       0      22       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     416     209     210       0      22       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     417     210     211       0      22       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     418     211     212       0      22       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     419     212      57       0      22       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     420     213     214       0      22       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     421     214     215       0      22       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     422     215     216       0      22       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     423     216     217       0      22       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     424     217      56       0      22       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     425     218      59       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     426     219      62       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     427     220      66       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     428     221       4       0       1       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     429     222       2       0       1       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     430     223       6       0       1       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     431     224      94       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     432     225      60       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     433     226      61       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     434     227      52       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     435     228      63       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     436     229      65       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     437     230      51       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     438     231      92       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     439     232      93       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     440     233      53       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     441     234      95       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     442     235      96       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     443     236      55       0      25       0       0  0.00000E+00  3.42020E-01 -9.39690E-01
     444     237     238       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     445     238     239       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     446     239       2       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     447     240     241       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     448     241     242       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     449     242       2       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     450     243     244       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     451     244     245       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     452     245       6       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     453     246     247       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     454     247     248       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     455     248       6       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     456     249     250       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     457     250     251       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     458     251       4       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     459     252     253       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     460     253     254       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     461     254       4       0       2       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     462     255     256       0      11       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     463     256     257       0      11       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     464     257       8       0      11       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     465     258     259       0      11       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     466     259     260       0      11       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     467     260       7       0      11       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     468     261     262       0      12       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     469     262     263       0      12       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     470     263       7       0      12       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     471     264     265       0      12       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     472     265     266       0      12       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     473     266       8       0      12       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     474     267     268       0      13       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     475     268     269       0      13       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     476     269      67       0      13       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     477     270     271       0      13       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     478     271     272       0      13       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     479     272      68       0      13       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     480     273     274       0      14       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     481     274     275       0      14       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     482     275       7       0      14       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     483     276     277       0      14       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     484     277     278       0      14       0       0  0.00000E+00  1.00000E+00  0.00000E+00  
     %501      83      79       0      99       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     %502      83      80       0      99       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     %503      83      81       0      99       0       0  0.00000E+00  1.00000E+00  0.00000E+00
     %504      83      82       0      99       0       0  0.00000E+00  1.00000E+00  0.00000E+00 
  ];
  
% Create bar element property matrix
propbar=[ ...
%  pid      mid        A           I22           I33          J        nsm/elem     nsm/length        K1           K2           C1           C2           D1           D2           E1           E2           F1           F2
       1       1  A_sptop      0.47840E-05  0.16260E-05  0.37970E-05  0.00000E+00  0.00000E+00  0.63662E+00  0.24174E+00 -0.80000E-01  0.40000E-01 -0.80000E-01 -0.40000E-01  0.80000E-01 -0.40000E-01  0.80000E-01  0.40000E-01
       2       1  A_spbot      I_sp         I_sp         J_sp         0.00000E+00  0.00000E+00  0.53304E+00  0.53304E+00 -0.30000E-01  0.00000E+00  0.00000E+00 -0.30000E-01  0.30000E-01  0.00000E+00  0.00000E+00  0.30000E-01
      11       1  0.63150E-03  0.35500E-06  0.35500E-06  0.71000E-06  0.00000E+00  0.00000E+00  0.53238E+00  0.53238E+00 -0.35000E-01  0.00000E+00  0.00000E+00 -0.35000E-01  0.35000E-01  0.00000E+00  0.00000E+00  0.35000E-01
      12       1  0.44300E-03  0.12280E-06  0.12280E-06  0.24560E-06  0.00000E+00  0.00000E+00  0.53414E+00  0.53414E+00 -0.25000E-01  0.00000E+00  0.00000E+00 -0.25000E-01  0.25000E-01  0.00000E+00  0.00000E+00  0.25000E-01
      13       1  0.63150E-03  0.35500E-06  0.35500E-06  0.71000E-06  0.00000E+00  0.00000E+00  0.53238E+00  0.53238E+00 -0.35000E-01  0.00000E+00  0.00000E+00 -0.35000E-01  0.35000E-01  0.00000E+00  0.00000E+00  0.35000E-01
      14       1  0.63150E-03  0.35500E-06  0.35500E-06  0.71000E-06  0.00000E+00  0.00000E+00  0.53238E+00  0.53238E+00 -0.35000E-01  0.00000E+00  0.00000E+00 -0.35000E-01  0.35000E-01  0.00000E+00  0.00000E+00  0.35000E-01
      21       2  0.91420E-03  I_ss         10*I_ss      2*I_ss       0.00000E+00  0.00000E+00  0.53149E+00  0.53149E+00 -0.50000E-01  0.00000E+00  0.00000E+00 -0.50000E-01  0.50000E-01  0.00000E+00  0.00000E+00  0.50000E-01
      22       3  0.31250E-01  0.66630E-07  0.42660E-02  0.12400E-03  0.00000E+00  0.79400E+01  0.90170E+00  0.84969E+00 -0.12500E-01  0.62500E+00 -0.12500E-01 -0.62500E+00  0.12500E-01 -0.62500E+00  0.12500E-01  0.62500E+00
      25       2  0.91420E-03  I_ss         10*I_ss      2*I_ss       0.00000E+00  0.00000E+00  0.53149E+00  0.53149E+00 -0.50000E-01  0.00000E+00  0.00000E+00 -0.50000E-01  0.50000E-01  0.00000E+00  0.00000E+00  0.50000E-01
      65       2  0.91420E-03  0.64500E-09  0.64530E-08  0.15600E-07  0.00000E+00  0.00000E+00  0.53149E+00  0.53149E+00 -0.50000E-01  0.00000E+00  0.00000E+00 -0.50000E-01  0.50000E-01  0.00000E+00  0.00000E+00  0.50000E-01
      66       2  0.91420E-03  0.64500E-09  0.64530E-08  0.15600E-07  0.00000E+00  0.00000E+00  0.53149E+00  0.53149E+00 -0.50000E-01  0.00000E+00  0.00000E+00 -0.50000E-01  0.50000E-01  0.00000E+00  0.00000E+00  0.50000E-01
      %99       2  1.96350E-03  I_iso        I_iso        1.00000E-03  0.00000E+00  0.00000E+00  0.53149E+00  0.53149E+00 -0.50000E-01  0.00000E+00  0.00000E+00 -0.50000E-01  0.50000E-01  0.00000E+00  0.00000E+00  0.50000E-01
];
  
nicelas2= [ ...
      21      15       1      38       1  K_act1  0.00000E+00
      22      15       2      38       2  K_act2  0.00000E+00
      23      15       3      38       3  K_act2  0.00000E+00
      24      15       4      38       4  K_rad1  0.00000E+00
      25      15       5      38       5  K_rad2  0.00000E+00
      27      15       6      38       6  K_rad2  0.00000E+00
      28      14       1      37       1  K_act1  0.00000E+00
      29      16       1      42       1  K_act1  0.00000E+00
      30      17       1      41       1  K_act1  0.00000E+00
      31      19       1      40       1  K_act1  0.00000E+00
      32      18       1      39       1  K_act1  0.00000E+00
      33      20       1      31       1  K_act1  0.00000E+00
      34      21       1      32       1  K_act1  0.00000E+00
      35      25       1      33       1  K_act1  0.00000E+00
      36      26       1      34       1  K_act1  0.00000E+00
      37      24       1      35       1  K_act1  0.00000E+00
      38      23       1      36       1  K_act1  0.00000E+00
      39      14       2      37       2  K_act2  0.00000E+00
      40      16       2      42       2  K_act2  0.00000E+00
      41      17       2      41       2  K_act2  0.00000E+00
      42      19       2      40       2  K_act2  0.00000E+00
      43      18       2      39       2  K_act2  0.00000E+00
      44      20       2      31       2  K_act2  0.00000E+00
      45      21       2      32       2  K_act2  0.00000E+00
      46      25       2      33       2  K_act2  0.00000E+00
      47      26       2      34       2  K_act2  0.00000E+00
      48      24       2      35       2  K_act2  0.00000E+00
      49      23       2      36       2  K_act2  0.00000E+00
      50      14       3      37       3  K_act2  0.00000E+00
      51      16       3      42       3  K_act2  0.00000E+00
      52      17       3      41       3  K_act2  0.00000E+00
      53      19       3      40       3  K_act2  0.00000E+00
      54      18       3      39       3  K_act2  0.00000E+00
      55      20       3      31       3  K_act2  0.00000E+00
      56      21       3      32       3  K_act2  0.00000E+00
      57      25       3      33       3  K_act2  0.00000E+00
      58      26       3      34       3  K_act2  0.00000E+00
      59      24       3      35       3  K_act2  0.00000E+00
      60      23       3      36       3  K_act2  0.00000E+00
      61      14       4      37       4  K_rad1  0.00000E+00
      62      16       4      42       4  K_rad1  0.00000E+00
      63      17       4      41       4  K_rad1  0.00000E+00
      64      19       4      40       4  K_rad1  0.00000E+00
      65      18       4      39       4  K_rad1  0.00000E+00
      66      20       4      31       4  K_rad1  0.00000E+00
      67      21       4      32       4  K_rad1  0.00000E+00
      68      25       4      33       4  K_rad1  0.00000E+00
      69      26       4      34       4  K_rad1  0.00000E+00
      70      24       4      35       4  K_rad1  0.00000E+00
      71      23       4      36       4  K_rad1  0.00000E+00
      72      14       5      37       5  K_rad2  0.00000E+00
      73      16       5      42       5  K_rad2  0.00000E+00
      74      17       5      41       5  K_rad2  0.00000E+00
      75      19       5      40       5  K_rad2  0.00000E+00
      76      18       5      39       5  K_rad2  0.00000E+00
      77      20       5      31       5  K_rad2  0.00000E+00
      78      21       5      32       5  K_rad2  0.00000E+00
      79      25       5      33       5  K_rad2  0.00000E+00
      80      26       5      34       5  K_rad2  0.00000E+00
      81      24       5      35       5  K_rad2  0.00000E+00
      82      23       5      36       5  K_rad2  0.00000E+00
      83      14       6      37       6  K_rad2  0.00000E+00
      84      16       6      42       6  K_rad2  0.00000E+00
      85      17       6      41       6  K_rad2  0.00000E+00
      86      19       6      40       6  K_rad2  0.00000E+00
      87      18       6      39       6  K_rad2  0.00000E+00
      88      20       6      31       6  K_rad2  0.00000E+00
      89      21       6      32       6  K_rad2  0.00000E+00
      90      25       6      33       6  K_rad2  0.00000E+00
      91      26       6      34       6  K_rad2  0.00000E+00
      92      24       6      35       6  K_rad2  0.00000E+00
      93      23       6      36       6  K_rad2  0.00000E+00
     141      78       2      90       2  K_yISO  0.00000E+00
     142      74       2      86       2  K_yISO  0.00000E+00
     143      76       2      88       2  K_yISO  0.00000E+00
     144     111       2     114       2  K_yISO  0.00000E+00
     145     109       2     112       2  K_yISO  0.00000E+00
     146     110       2     113       2  K_yISO  0.00000E+00
     147      73       2      85       2  K_yISO  0.00000E+00
     148      77       2      89       2  K_yISO  0.00000E+00
     149      75       2      87       2  K_yISO  0.00000E+00
     150     103       2     104       2  K_yISO  0.00000E+00
     151     107       2     108       2  K_yISO  0.00000E+00
     152     105       2     106       2  K_yISO  0.00000E+00
     153      78       1      90       1  K_xISO  0.00000E+00
     154      74       1      86       1  K_xISO  0.00000E+00
     155      76       1      88       1  K_xISO  0.00000E+00
     156     111       1     114       1  K_xISO  0.00000E+00
     157     109       1     112       1  K_xISO  0.00000E+00
     164     110       1     113       1  K_xISO  0.00000E+00
     165      73       1      85       1  K_xISO  0.00000E+00
     166      77       1      89       1  K_xISO  0.00000E+00
     167      75       1      87       1  K_xISO  0.00000E+00
     168     103       1     104       1  K_xISO  0.00000E+00
     169     107       1     108       1  K_xISO  0.00000E+00
     170     105       1     106       1  K_xISO  0.00000E+00
     171      78       3      90       3  K_xISO  0.00000E+00
     172      74       3      86       3  K_xISO  0.00000E+00
     173      76       3      88       3  K_xISO  0.00000E+00
     174     111       3     114       3  K_xISO  0.00000E+00
     175     109       3     112       3  K_xISO  0.00000E+00
     176     110       3     113       3  K_xISO  0.00000E+00
     177      73       3      85       3  K_xISO  0.00000E+00
     178      77       3      89       3  K_xISO  0.00000E+00
     179      75       3      87       3  K_xISO  0.00000E+00
     180     103       3     104       3  K_xISO  0.00000E+00
     181     107       3     108       3  K_xISO  0.00000E+00
     182     105       3     106       3  K_xISO  0.00000E+00
     183      78       4      90       4  K_rISO  0.00000E+00
     184      74       4      86       4  K_rISO  0.00000E+00
     185      76       4      88       4  K_rISO  0.00000E+00
     186     111       4     114       4  K_rISO  0.00000E+00
     187     109       4     112       4  K_rISO  0.00000E+00
     188     110       4     113       4  K_rISO  0.00000E+00
     189      73       4      85       4  K_rISO  0.00000E+00
     190      77       4      89       4  K_rISO  0.00000E+00
     191      75       4      87       4  K_rISO  0.00000E+00
     192     103       4     104       4  K_rISO  0.00000E+00
     193     107       4     108       4  K_rISO  0.00000E+00
     194     105       4     106       4  K_rISO  0.00000E+00
     195      78       5      90       5  K_aISO  0.00000E+00
     196      74       5      86       5  K_aISO  0.00000E+00
     197      76       5      88       5  K_aISO  0.00000E+00
     198     111       5     114       5  K_aISO  0.00000E+00
     199     109       5     112       5  K_aISO  0.00000E+00
     200     110       5     113       5  K_aISO  0.00000E+00
     201      73       5      85       5  K_aISO  0.00000E+00
     202      77       5      89       5  K_aISO  0.00000E+00
     203      75       5      87       5  K_aISO  0.00000E+00
     204     103       5     104       5  K_aISO  0.00000E+00
     205     107       5     108       5  K_aISO  0.00000E+00
     206     105       5     106       5  K_aISO  0.00000E+00
     207      78       6      90       6  K_rISO  0.00000E+00
     208      74       6      86       6  K_rISO  0.00000E+00
     209      76       6      88       6  K_rISO  0.00000E+00
     210     111       6     114       6  K_rISO  0.00000E+00
     211     109       6     112       6  K_rISO  0.00000E+00
     212     110       6     113       6  K_rISO  0.00000E+00
     213      73       6      85       6  K_rISO  0.00000E+00
     214      77       6      89       6  K_rISO  0.00000E+00
     215      75       6      87       6  K_rISO  0.00000E+00
     216     103       6     104       6  K_rISO  0.00000E+00
     217     107       6     108       6  K_rISO  0.00000E+00
     218     105       6     106       6  K_rISO  0.00000E+00
     228     131       1     124       1  0.10000E+07  0.00000E+00
     229     132       1     123       1  0.10000E+07  0.00000E+00
     230     133       1     122       1  0.10000E+07  0.00000E+00
     231     134       1     115       1  0.10000E+07  0.00000E+00
     232     135       1      29       1  0.10000E+07  0.00000E+00
     233     136       1     125       1  0.10000E+07  0.00000E+00
     234     131       2     124       2  K_yPM  0.00000E+00
     235     132       2     123       2  K_yPM  0.00000E+00
     236     133       2     122       2  K_yPM  0.00000E+00
     237     134       2     115       2  K_yPM  0.00000E+00
     238     135       2      29       2  K_yPM  0.00000E+00
     239     136       2     125       2  K_yPM  0.00000E+00
     240     131       3     124       3  0.58400E+06  0.00000E+00
     241     132       3     123       3  0.58400E+06  0.00000E+00
     242     133       3     122       3  0.58400E+06  0.00000E+00
     243     134       3     115       3  0.58400E+06  0.00000E+00
     244     135       3      29       3  0.58400E+06  0.00000E+00
     245     136       3     125       3  0.58400E+06  0.00000E+00
     246     131       4     124       4  0.59820E+02  0.00000E+00
     247     132       4     123       4  0.59820E+02  0.00000E+00
     248     133       4     122       4  0.59820E+02  0.00000E+00
     249     134       4     115       4  0.59820E+02  0.00000E+00
     250     135       4      29       4  0.59820E+02  0.00000E+00
     251     136       4     125       4  0.59820E+02  0.00000E+00
     252     131       5     124       5  0.49000E+02  0.00000E+00
     253     132       5     123       5  0.49000E+02  0.00000E+00
     254     133       5     122       5  0.49000E+02  0.00000E+00
     255     134       5     115       5  0.49000E+02  0.00000E+00
     256     135       5      29       5  0.49000E+02  0.00000E+00
     257     136       5     125       5  0.49000E+02  0.00000E+00
     258     131       6     124       6  0.33250E+02  0.00000E+00
     259     132       6     123       6  0.33250E+02  0.00000E+00
     260     133       6     122       6  0.33250E+02  0.00000E+00
     261     134       6     115       6  0.33250E+02  0.00000E+00
     262     135       6      29       6  0.33250E+02  0.00000E+00
     263     136       6     125       6  0.33250E+02  0.00000E+00
     264     137       1     126       1  K_act2  0.00000E+00
     265     138       1     128       1  K_act2  0.00000E+00
     266     139       1     127       1  K_act2  0.00000E+00
     267     137       2     126       2  0.29100E+07  0.00000E+00
     268     138       2     128       2  0.29100E+07  0.00000E+00
     269     139       2     127       2  0.29100E+07  0.00000E+00
     270     137       3     126       3  0.10000E+07  0.00000E+00
     271     138       3     128       3  0.10000E+07  0.00000E+00
     272     139       3     127       3  0.10000E+07  0.00000E+00
     273     137       4     126       4  0.33250E+02  0.00000E+00
     274     138       4     128       4  0.33250E+02  0.00000E+00
     275     139       4     127       4  0.33250E+02  0.00000E+00
     276     137       5     126       5  0.49000E+02  0.00000E+00
     277     138       5     128       5  0.49000E+02  0.00000E+00
     278     139       5     127       5  0.49000E+02  0.00000E+00
     279     137       6     126       6  0.12012E+03  0.00000E+00
     280     138       6     128       6  0.12012E+03  0.00000E+00
     281     139       6     127       6  0.12012E+03  0.00000E+00
     284     151       1     144       1  0.10000E+07  0.00000E+00
     285     152       1     143       1  0.10000E+07  0.00000E+00
     286     153       1     142       1  0.10000E+07  0.00000E+00
     287     154       1     141       1  0.10000E+07  0.00000E+00
     288     155       1     140       1  0.10000E+07  0.00000E+00
     289     156       1     145       1  0.10000E+07  0.00000E+00
     290     151       2     144       2  K_yPM  0.00000E+00
     291     152       2     143       2  K_yPM  0.00000E+00
     292     153       2     142       2  K_yPM  0.00000E+00
     293     154       2     141       2  K_yPM  0.00000E+00
     294     155       2     140       2  K_yPM  0.00000E+00
     295     156       2     145       2  K_yPM  0.00000E+00
     296     151       3     144       3  0.58400E+06  0.00000E+00
     297     152       3     143       3  0.58400E+06  0.00000E+00
     298     153       3     142       3  0.58400E+06  0.00000E+00
     299     154       3     141       3  0.58400E+06  0.00000E+00
     300     155       3     140       3  0.58400E+06  0.00000E+00
     301     156       3     145       3  0.58400E+06  0.00000E+00
     302     151       4     144       4  0.59820E+02  0.00000E+00
     303     152       4     143       4  0.59820E+02  0.00000E+00
     304     153       4     142       4  0.59820E+02  0.00000E+00
     305     154       4     141       4  0.59820E+02  0.00000E+00
     306     155       4     140       4  0.59820E+02  0.00000E+00
     307     156       4     145       4  0.59820E+02  0.00000E+00
     308     151       5     144       5  0.49000E+02  0.00000E+00
     309     152       5     143       5  0.49000E+02  0.00000E+00
     310     153       5     142       5  0.49000E+02  0.00000E+00
     311     154       5     141       5  0.49000E+02  0.00000E+00
     312     155       5     140       5  0.49000E+02  0.00000E+00
     313     156       5     145       5  0.49000E+02  0.00000E+00
     314     151       6     144       6  0.33250E+02  0.00000E+00
     315     152       6     143       6  0.33250E+02  0.00000E+00
     316     153       6     142       6  0.33250E+02  0.00000E+00
     317     154       6     141       6  0.33250E+02  0.00000E+00
     318     155       6     140       6  0.33250E+02  0.00000E+00
     319     156       6     145       6  0.33250E+02  0.00000E+00
     320     157       1     146       1  K_act2  0.00000E+00
     321     158       1     148       1  K_act2  0.00000E+00
     322     159       1     147       1  K_act2  0.00000E+00
     323     157       2     146       2  0.29100E+07  0.00000E+00
     324     158       2     148       2  0.29100E+07  0.00000E+00
     325     159       2     147       2  0.29100E+07  0.00000E+00
     326     157       3     146       3  0.10000E+07  0.00000E+00
     327     158       3     148       3  0.10000E+07  0.00000E+00
     328     159       3     147       3  0.10000E+07  0.00000E+00
     329     157       4     146       4  0.33250E+02  0.00000E+00
     330     158       4     148       4  0.33250E+02  0.00000E+00
     331     159       4     147       4  0.33250E+02  0.00000E+00
     332     157       5     146       5  0.49000E+02  0.00000E+00
     333     158       5     148       5  0.49000E+02  0.00000E+00
     334     159       5     147       5  0.49000E+02  0.00000E+00
     335     157       6     146       6  0.12012E+03  0.00000E+00
     336     158       6     148       6  0.12012E+03  0.00000E+00
     337     159       6     147       6  0.12012E+03  0.00000E+00
     340     171       1     164       1  0.10000E+07  0.00000E+00
     341     172       1     163       1  0.10000E+07  0.00000E+00
     342     173       1     162       1  0.10000E+07  0.00000E+00
     343     174       1     161       1  0.10000E+07  0.00000E+00
     344     175       1     160       1  0.10000E+07  0.00000E+00
     345     176       1     165       1  0.10000E+07  0.00000E+00
     346     171       2     164       2  K_yPM  0.00000E+00
     347     172       2     163       2  K_yPM  0.00000E+00
     348     173       2     162       2  K_yPM  0.00000E+00
     349     174       2     161       2  K_yPM  0.00000E+00
     350     175       2     160       2  K_yPM  0.00000E+00
     351     176       2     165       2  K_yPM  0.00000E+00
     352     171       3     164       3  0.58400E+06  0.00000E+00
     353     172       3     163       3  0.58400E+06  0.00000E+00
     354     173       3     162       3  0.58400E+06  0.00000E+00
     355     174       3     161       3  0.58400E+06  0.00000E+00
     356     175       3     160       3  0.58400E+06  0.00000E+00
     357     176       3     165       3  0.58400E+06  0.00000E+00
     358     171       4     164       4  0.59820E+02  0.00000E+00
     359     172       4     163       4  0.59820E+02  0.00000E+00
     360     173       4     162       4  0.59820E+02  0.00000E+00
     361     174       4     161       4  0.59820E+02  0.00000E+00
     362     175       4     160       4  0.59820E+02  0.00000E+00
     363     176       4     165       4  0.59820E+02  0.00000E+00
     364     171       5     164       5  0.49000E+02  0.00000E+00
     365     172       5     163       5  0.49000E+02  0.00000E+00
     366     173       5     162       5  0.49000E+02  0.00000E+00
     367     174       5     161       5  0.49000E+02  0.00000E+00
     368     175       5     160       5  0.49000E+02  0.00000E+00
     369     176       5     165       5  0.49000E+02  0.00000E+00
     370     171       6     164       6  0.33250E+02  0.00000E+00
     371     172       6     163       6  0.33250E+02  0.00000E+00
     372     173       6     162       6  0.33250E+02  0.00000E+00
     373     174       6     161       6  0.33250E+02  0.00000E+00
     374     175       6     160       6  0.33250E+02  0.00000E+00
     375     176       6     165       6  0.33250E+02  0.00000E+00
     376     177       1     166       1  K_act2  0.00000E+00
     377     178       1     168       1  K_act2  0.00000E+00
     378     179       1     167       1  K_act2  0.00000E+00
     379     177       2     166       2  0.29100E+07  0.00000E+00
     380     178       2     168       2  0.29100E+07  0.00000E+00
     381     179       2     167       2  0.29100E+07  0.00000E+00
     382     177       3     166       3  0.10000E+07  0.00000E+00
     383     178       3     168       3  0.10000E+07  0.00000E+00
     384     179       3     167       3  0.10000E+07  0.00000E+00
     385     177       4     166       4  0.33250E+02  0.00000E+00
     386     178       4     168       4  0.33250E+02  0.00000E+00
     387     179       4     167       4  0.33250E+02  0.00000E+00
     388     177       5     166       5  0.49000E+02  0.00000E+00
     389     178       5     168       5  0.49000E+02  0.00000E+00
     390     179       5     167       5  0.49000E+02  0.00000E+00
     391     177       6     166       6  0.12012E+03  0.00000E+00
     392     178       6     168       6  0.12012E+03  0.00000E+00
     393     179       6     167       6  0.12012E+03  0.00000E+00
     395     197       3     192       3  K_zpet  0.00000E+00
     396     196       3     190       3  K_zpet  0.00000E+00
     397     198       3     193       3  K_zpet  0.00000E+00
     398     195       3     191       3  K_zpet  0.00000E+00
     399     198       1     193       1  0.18000E+10  0.00000E+00
     400     198       2     193       2  0.18000E+10  0.00000E+00
     401     195       2     191       2  0.18000E+10  0.00000E+00
  ];
  
%==============================================================
% 4. Create Material matrix
%==============================================================

mat=0;
mid=       1;
E=   0.89800E+11;
nu=  0.31000E+00;
rho=  0.16643E+04;
alpha=  0.56300E-07;
Tref=  0.00000E+00;
mat=mat1(mid,E,nu,rho,alpha,Tref,mat);
 
% WARNING: G-IMOS IS DIFFERENT THAN G-NASTRAN
 
mid=       2;
E=  0.89800E+11;
nu=  0.31000E+00;
rho=  0.00000E+00;
alpha=  0.56300E-07;
Tref=  0.00000E+00;
mat=mat1(mid,E,nu,rho,alpha,Tref,mat);
 
% WARNING: G-IMOS IS DIFFERENT THAN G-NASTRAN
 
mid=       3;
E=  0.89800E+11;
nu=  0.31000E+00;
rho=  0.00000E+00;
alpha=  0.56300E-07;
Tref=  0.00000E+00;
mat=mat1(mid,E,nu,rho,alpha,Tref,mat);
 
 
%==============================================================
% 4. Define Concentrated Masses
%==============================================================

  
niconm2= [ ...
      12      22  m_SM  0.00000E+00  0.00000E+00  0.00000E+00  0.22300E-01  0.42990E-01  0.22300E-01  0.00000E+00  0.00000E+00  0.00000E+00
      13      13  m_SMhub  0.00000E+00  0.00000E+00  0.00000E+00  I_SMhubt  I_SMhuba  I_SMhubt  0.00000E+00  0.00000E+00  0.00000E+00
     100      45  0.57000E+01  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00
     101      44  0.57000E+01  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00
     102      43  0.57000E+01  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00
     103      46  0.57000E+01  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00
     104      51  0.10000E+01  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00
     105      53  0.10000E+01  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00
     106      52  0.10000E+01  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00
     107      55  0.10000E+01  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00
     135      84  m_bus  0.00000E+00  0.00000E+00  0.00000E+00  I_bus  I_bus  I_bus  0.00000E+00  0.00000E+00  0.00000E+00
     136      84  m_prop  0.00000E+00  0.00000E+00  0.00000E+00 I_propt  I_propa I_propt  0.00000E+00  0.00000E+00  0.00000E+00
     137      79  m_RW  0.00000E+00  0.00000E+00  0.00000E+00  I_RWt  0.14339E+00  I_RWt  0.00000E+00  0.00000E+00  0.00000E+00
     138      80  m_RW  0.00000E+00  0.00000E+00  0.00000E+00  I_RWt  0.14339E+00  I_RWt  0.00000E+00  0.00000E+00  0.00000E+00
     139      81  m_RW  0.00000E+00  0.00000E+00  0.00000E+00  I_RWt  0.14339E+00  I_RWt  0.00000E+00  0.00000E+00  0.00000E+00
     140      82  m_RW  0.00000E+00  0.00000E+00  0.00000E+00  I_RWt  0.14339E+00  I_RWt  0.00000E+00  0.00000E+00  0.00000E+00
     158     116  0.70000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.56450E-04  0.20250E-02  0.20250E-02  0.00000E+00  0.00000E+00  0.00000E+00
     159     117  0.70000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.56450E-04  0.20250E-02  0.20250E-02  0.00000E+00  0.00000E+00  0.00000E+00
     160     118  0.70000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.56450E-04  0.20250E-02  0.20250E-02  0.00000E+00  0.00000E+00  0.00000E+00
     161     119  0.70000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.56450E-04  0.20250E-02  0.20250E-02  0.00000E+00  0.00000E+00  0.00000E+00
     162     120  0.70000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.56450E-04  0.20250E-02  0.20250E-02  0.00000E+00  0.00000E+00  0.00000E+00
     163     121  0.70000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.56450E-04  0.20250E-02  0.20250E-02  0.00000E+00  0.00000E+00  0.00000E+00
     219     102  m_ISO  0.00000E+00  0.00000E+00  0.00000E+00  I_ISOt  I_ISOa  I_ISOt  0.00000E+00  0.00000E+00  0.00000E+00
     220     101  m_ISO  0.00000E+00  0.00000E+00  0.00000E+00  I_ISOt  I_ISOa  I_ISOt  0.00000E+00  0.00000E+00  0.00000E+00
     221     100  m_ISO  0.00000E+00  0.00000E+00  0.00000E+00  I_ISOt  I_ISOa  I_ISOt  0.00000E+00  0.00000E+00  0.00000E+00
     222      98  m_ISO  0.00000E+00  0.00000E+00  0.00000E+00  I_ISOt  I_ISOa  I_ISOt  0.00000E+00  0.00000E+00  0.00000E+00
     223      99  m_ISO  0.00000E+00  0.00000E+00  0.00000E+00  I_ISOt  I_ISOa  I_ISOt  0.00000E+00  0.00000E+00  0.00000E+00
     224      97  m_ISO  0.00000E+00  0.00000E+00  0.00000E+00  I_ISOt  I_ISOa  I_ISOt  0.00000E+00  0.00000E+00  0.00000E+00
     225      83  m_RWAchx  0.00000E+00  0.00000E+00  0.00000E+00  I_xRWA  I_yRWA  I_zRWA  0.00000E+00  0.00000E+00  0.00000E+00
     227     130  0.10780E+02  0.00000E+00  0.00000E+00  0.00000E+00  0.10271E+01  0.20347E+01  0.10156E+01  0.00000E+00  0.00000E+00  0.00000E+00
     283     150  0.10780E+02  0.00000E+00  0.00000E+00  0.00000E+00  0.10271E+01  0.20347E+01  0.10156E+01  0.00000E+00  0.00000E+00  0.00000E+00
     339     170  0.10780E+02  0.00000E+00  0.00000E+00  0.00000E+00  0.10271E+01  0.20347E+01  0.10156E+01  0.00000E+00  0.00000E+00  0.00000E+00
     402      91  0.59640E+02  0.00000E+00  0.00000E+00  0.16800E+00  0.13340E+02  0.40470E+02  0.27530E+02  0.00000E+00  0.00000E+00  0.00000E+00
     403     194  0.18860E+02  0.00000E+00  0.00000E+00  0.00000E+00  0.16190E+01  0.29690E+01  0.14760E+01  0.00000E+00  0.00000E+00  0.00000E+00
     404      52  0.49600E+01  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00
     405      53  0.49600E+01  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00
     406      51  0.49600E+01  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00
     407      55  0.92600E+01  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00
     408      45  0.49600E+01  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00
     409      46  0.49600E+01  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00
     410      43  0.49600E+01  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00
     411      44  0.92600E+01  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00  0.00000E+00
     414     207  m_instr      0.00000E+00  0.00000E+00  0.00000E+00  I_i1         I_i2         I_i3  0.00000E+00  0.00000E+00  0.00000E+00
  ];
  
cmcid2= [ ...
       0
       0
       3
       3
       3
       3
       3
       3
       3
       3
       3
       3
       4
       5
       6
       7
      80
      79
      78
      77
      76
      75
      12
      11
      13
      10
       8
       9
       3
      17
      29
      34
       0
      17
       3
       3
       3
       3
       3
       3
       3
       3
       3
  ];
  
%==============================================================
% 5. Define Boundary Conditions and Initialize m and k
%==============================================================

  % Create initial boundary condition matrix
  %  (0= constrain, 1= free)
bci=ones(273,6);
  
 %  Compute the number of dofs and dof numbers, initialize k and m
[bc,ndof]=bcond(bci);
nset=[1:ndof];
fset=nset;
k=sparse(ndof,ndof);
m=k;
g=k;

%==============================================================
% 6. Assembly of m and k
%==============================================================
  if diagnostics
     disp('Assembling m for conm2s')
     end
     m=conm2(niconm2,bc,m,xyz,cmcid2,cf);
     if diagnostics
        disp('Assembling k and m for beams')
        end
        [k,m]=beam_lump(nibar,xyz,propbar,mat,bc,k,m,ti,tf);
        if diagnostics
           disp('Transforming k and m to local cs')
           end
           [k,m]=km2loc(k,m,ti,tf);
           if diagnostics
              disp( 'Assembling k for spring elements')
              end
              [k,g]=celas2(nicelas2,xyz,bc,k,g);
  
%==============================================================
% 7. Determine Mass Properties and RBM's
%==============================================================
% compute rigid body modes geometrically,
% where the rotation point is the c.g. and compute mass properties
%[xyzcg]=cg_calc(m,xyz,bc,ti,tf);
[xyzcg]=cg_calc(m,xyz,bc);
%mass=wtcg(bc,xyz,m,xyzcg);
Rpt=xyzcg;
phirb=rbmodes(bc,xyz,m,Rpt);
phirb=normphi(phirb,m);
%==============================================================
% 8. Process Rigid Body elements
%==============================================================
  rg=[0];
  mset=[0];
  nirbe=[];
  mapdof=[];
  for ind=1:size(xyz,1)
     ids(xyz(ind,1))=ind;
  end
  bci=bc;
  % secondary mirror hub
  if diagnostics
     disp('Processing RBE2 rigid body elements')
     end
gn=[      13];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
       3
      15
      14
      18
       1
      19
      16
      17
       5
    ];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
    nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    [nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);


% secondary mirror RBE2
gn=[      22];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
      20
      21
      25
      26
      24
      23
     202
  ];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
    nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[      38];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
      31
     118
  ];
  nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[      39];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
      32
     119
  ];
  nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[      40];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
      33
     120
  ];
  nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[      41];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
      34
     121
  ];
  nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[      42];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
      35
     116
  ];
  nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[      37];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
      36
     117
  ];
  nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
  [nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
  % Spacecraft Rigid Element
gn=[      84]; % independent node S/C CM
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
      27
      28
      30
      64
      71
      72
      69
      70
      86
      88
      90
      48
      47
      50
      49
      44
      45
      46
      43
      58
     112
     113
     114
  ];
  % 27,28,30,64 S/C top corner
  % 71,72,69,70 bottom 4 attach points to Launch Vehicle
  % 86(112) , 88(113), 90(114) RWA attach points
  % 48, 50 solar array attach
  % 47, 49 mid point, S/C bottom edge (pitch)
  % 43-46   sunshield
     % 58 origin (not CM)
     % omitted for clarity nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[     111];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
     103
      97
   ];
   nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[      74];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
      73
      98
   ];
   nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[      78];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
      77
      99
   ];
   nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[     110];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
     107
     100
  ];
  nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[      76];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
      75
     102
  ];
  nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[     109];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
     105
     101
  ];
  nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
  [nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
  % RWA Chassis RBE
gn=[      83];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
      81 % replace with axle stiffness
      82
      79
      80
      85
      87
      89
     104
     106
     108
  ];
  nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[      91];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
      11
      12
       8
       7
       9
      10
      67
      68
     173
     174
     175
     176
     171
     172
     179
     177
     178
     155
     156
     151
     152
     153
     154
     157
     158
     159
     185
     183
     184
     196
     195
     197
     198
     200
     199
     201
     207
  ];
  % omitted for clarity nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[     130];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
     125
     124
     123
     122
     115
      29
     126
     128
     127
     129
  ];
  nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[     150];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
     145
     144
     143
     142
     141
     140
     146
     148
     147
     149
  ];
  nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[     170];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
     165
     164
     163
     162
     161
     160
     166
     168
     167
     169
  ];
  nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[     194];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
     190
     191
     192
     193
     135
     182
     136
     131
     180
     132
     133
     181
     134
     137
     138
     139
  ];
  % omit for clarity nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[      56];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
     205
     206
  ];
  nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
gn=[      57];
cm=[ ...
       1
       2
       3
       4
       5
       6
  ];
gm=[ ...
     204
     203
  ];
nirbe=[nirbe; [gn*ones(length(gm),1) gm]];
    mapdof=[mapdof; [reshape(bci(ids(gm),:)',length(gm)*6,1) repmat(bci(ids(gn),:)',length(gm),1)]];
[nset,mset,rg]=rbe2(bc,xyz,nset,mset,rg,gn,cm,gm,ti,tf);
rg=sparse(rg);
  if diagnostics
     disp('Reducing k and m to independent dofs')
  end
  [gm,k,m]=mce1(nset,mset,rg,k,m);
  bc=bcnset(bc,nset,mset);
  fset=nset;
  temp=reshape(bc',prod(size(bc)),1);
  mapdof(:,2)=temp(mapdof(:,2));
% End of model assembly script
